@@ -1,7 +1,9 @@
 from .parse_time import parse_time
 from .get_params import get_params
+from .random_string import random_string
 
 __all__ = [
     "parse_time",
-    "get_params"    
+    "get_params",
+    "random_string",
 ]
\ No newline at end of file
